summaryrefslogtreecommitdiff
path: root/PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlProxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlProxy.h')
-rw-r--r--PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlProxy.h71
1 files changed, 32 insertions, 39 deletions
diff --git a/PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlProxy.h b/PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlProxy.h
index bc0db84..4cc1ba0 100644
--- a/PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlProxy.h
+++ b/PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlProxy.h
@@ -1,22 +1,11 @@
/*
-* This file was generated by the CommonAPI Generators.
-* Used org.genivi.commonapi.core 2.1.2.201309301424.
-* Used org.franca.core 0.8.9.201308271211.
+* This file was generated by the CommonAPI Generators.
+* Used org.genivi.commonapi.core 2.1.5.201312121915.
+* Used org.franca.core 0.8.11.201401091023.
*
-* Copyright (c) 2012 BMW
-*
-* \author Aleksandar Donchev, aleksander.donchev@partner.bmw.de BMW 2013
-*
-* \copyright
-* Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction,
-* including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,
-* subject to the following conditions:
-* The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
-* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
-* THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-* For further information see http://www.genivi.org/.
-*
+* This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+* If a copy of the MPL was not distributed with this file, You can obtain one at
+* http://mozilla.org/MPL/2.0/.
*/
/**
* This class implements everything from Audiomanager -> RoutingAdapter
@@ -27,6 +16,7 @@
#include "RoutingControlProxyBase.h"
+
#if !defined (COMMONAPI_INTERNAL_COMPILATION)
#define COMMONAPI_INTERNAL_COMPILATION
#endif
@@ -39,11 +29,15 @@ namespace genivi {
namespace am {
template <typename ... _AttributeExtensions>
-class RoutingControlProxy: virtual public RoutingControl, virtual public RoutingControlProxyBase, public _AttributeExtensions... {
- public:
+class RoutingControlProxy: virtual public RoutingControl, virtual public RoutingControlProxyBase
+, public _AttributeExtensions... {
+public:
RoutingControlProxy(std::shared_ptr<CommonAPI::Proxy> delegate);
~RoutingControlProxy();
+ typedef RoutingControl InterfaceType;
+
+
/**
@@ -73,7 +67,7 @@ class RoutingControlProxy: virtual public RoutingControl, virtual public Routing
/**
* connects a source to a sink
(at)return E_OK on success, E_UNKNOWN on error,
* E_WRONG_FORMAT in case am_ConnectionFormat_e does not match
*
* Calls asyncConnect with synchronous semantics.
*
@@ -82,7 +76,7 @@ class RoutingControlProxy: virtual public RoutingControl, virtual public Routing
* "SUCCESS" or which type of error has occurred. In case of an error, ONLY the CallStatus
* will be set.
*/
- virtual void asyncConnect(const am_Handle_s& handle, const am_connectionID_t& connectionID, const am_sourceID_t& sourceID, const am_sinkID_t& sinkID, const am_ConnectionFormat_pe& connectionFormat, CommonAPI::CallStatus& callStatus);
+ virtual void asyncConnect(const am_Handle_s& handle, const am_connectionID_t& connectionID, const am_sourceID_t& sourceID, const am_sinkID_t& sinkID, const am_CustomConnectionFormat_t& connectionFormat, CommonAPI::CallStatus& callStatus);
/**
* Calls asyncConnect with asynchronous semantics.
*
@@ -93,7 +87,7 @@ class RoutingControlProxy: virtual public RoutingControl, virtual public Routing
* The std::future returned by this method will be fulfilled at arrival of the reply.
* It will provide the same value for CallStatus as will be handed to the callback.
*/
- virtual std::future<CommonAPI::CallStatus> asyncConnectAsync(const am_Handle_s& handle, const am_connectionID_t& connectionID, const am_sourceID_t& sourceID, const am_sinkID_t& sinkID, const am_ConnectionFormat_pe& connectionFormat, AsyncConnectAsyncCallback callback);
+ virtual std::future<CommonAPI::CallStatus> asyncConnectAsync(const am_Handle_s& handle, const am_connectionID_t& connectionID, const am_sourceID_t& sourceID, const am_sinkID_t& sinkID, const am_CustomConnectionFormat_t& connectionFormat, AsyncConnectAsyncCallback callback);
/**
* disconnect a connection with given connectionID
(at)return E_OK on success,
@@ -132,7 +126,7 @@ class RoutingControlProxy: virtual public RoutingControl, virtual public Routing
* "SUCCESS" or which type of error has occurred. In case of an error, ONLY the CallStatus
* will be set.
*/
- virtual void asyncSetSinkVolume(const am_Handle_s& handle, const am_sinkID_t& sinkID, const am_volume_t& volume, const am_RampType_pe& ramp, const am_time_t& time, CommonAPI::CallStatus& callStatus);
+ virtual void asyncSetSinkVolume(const am_Handle_s& handle, const am_sinkID_t& sinkID, const am_volume_t& volume, const am_CustomRampType_t& ramp, const am_time_t& time, CommonAPI::CallStatus& callStatus);
/**
* Calls asyncSetSinkVolume with asynchronous semantics.
*
@@ -143,7 +137,7 @@ class RoutingControlProxy: virtual public RoutingControl, virtual public Routing
* The std::future returned by this method will be fulfilled at arrival of the reply.
* It will provide the same value for CallStatus as will be handed to the callback.
*/
- virtual std::future<CommonAPI::CallStatus> asyncSetSinkVolumeAsync(const am_Handle_s& handle, const am_sinkID_t& sinkID, const am_volume_t& volume, const am_RampType_pe& ramp, const am_time_t& time, AsyncSetSinkVolumeAsyncCallback callback);
+ virtual std::future<CommonAPI::CallStatus> asyncSetSinkVolumeAsync(const am_Handle_s& handle, const am_sinkID_t& sinkID, const am_volume_t& volume, const am_CustomRampType_t& ramp, const am_time_t& time, AsyncSetSinkVolumeAsyncCallback callback);
/**
* sets the volume of a source. This method is used to set the volume of a sink.
* This function is used to drive ramps, to mute or unmute or directly set the
@@ -160,7 +154,7 @@ class RoutingControlProxy: virtual public RoutingControl, virtual public Routing
* "SUCCESS" or which type of error has occurred. In case of an error, ONLY the CallStatus
* will be set.
*/
- virtual void asyncSetSourceVolume(const am_Handle_s& handle, const am_sourceID_t& sourceID, const am_volume_t& volume, const am_RampType_pe& ramp, const am_time_t& time, CommonAPI::CallStatus& callStatus);
+ virtual void asyncSetSourceVolume(const am_Handle_s& handle, const am_sourceID_t& sourceID, const am_volume_t& volume, const am_CustomRampType_t& ramp, const am_time_t& time, CommonAPI::CallStatus& callStatus);
/**
* Calls asyncSetSourceVolume with asynchronous semantics.
*
@@ -171,7 +165,7 @@ class RoutingControlProxy: virtual public RoutingControl, virtual public Routing
* The std::future returned by this method will be fulfilled at arrival of the reply.
* It will provide the same value for CallStatus as will be handed to the callback.
*/
- virtual std::future<CommonAPI::CallStatus> asyncSetSourceVolumeAsync(const am_Handle_s& handle, const am_sourceID_t& sourceID, const am_volume_t& volume, const am_RampType_pe& ramp, const am_time_t& time, AsyncSetSourceVolumeAsyncCallback callback);
+ virtual std::future<CommonAPI::CallStatus> asyncSetSourceVolumeAsync(const am_Handle_s& handle, const am_sourceID_t& sourceID, const am_volume_t& volume, const am_CustomRampType_t& ramp, const am_time_t& time, AsyncSetSourceVolumeAsyncCallback callback);
/**
* This function is used to set the source state of a particular
* source.
@@ -304,7 +298,7 @@ class RoutingControlProxy: virtual public RoutingControl, virtual public Routing
* "SUCCESS" or which type of error has occurred. In case of an error, ONLY the CallStatus
* will be set.
*/
- virtual void asyncCrossFade(const am_Handle_s& handle, const am_crossfaderID_t& crossfaderID, const am_HotSink_e& hotSink, const am_RampType_pe& rampType, const am_time_t& time, CommonAPI::CallStatus& callStatus);
+ virtual void asyncCrossFade(const am_Handle_s& handle, const am_crossfaderID_t& crossfaderID, const am_HotSink_e& hotSink, const am_CustomRampType_t& rampType, const am_time_t& time, CommonAPI::CallStatus& callStatus);
/**
* Calls asyncCrossFade with asynchronous semantics.
*
@@ -315,7 +309,7 @@ class RoutingControlProxy: virtual public RoutingControl, virtual public Routing
* The std::future returned by this method will be fulfilled at arrival of the reply.
* It will provide the same value for CallStatus as will be handed to the callback.
*/
- virtual std::future<CommonAPI::CallStatus> asyncCrossFadeAsync(const am_Handle_s& handle, const am_crossfaderID_t& crossfaderID, const am_HotSink_e& hotSink, const am_RampType_pe& rampType, const am_time_t& time, AsyncCrossFadeAsyncCallback callback);
+ virtual std::future<CommonAPI::CallStatus> asyncCrossFadeAsync(const am_Handle_s& handle, const am_crossfaderID_t& crossfaderID, const am_HotSink_e& hotSink, const am_CustomRampType_t& rampType, const am_time_t& time, AsyncCrossFadeAsyncCallback callback);
/**
* this function is used for early and late audio functions to set the domain
* state
@@ -401,7 +395,7 @@ class RoutingControlProxy: virtual public RoutingControl, virtual public Routing
* It will provide the same value for CallStatus as will be handed to the callback.
*/
virtual std::future<CommonAPI::CallStatus> asyncSetSourceNotificationConfigurationAsync(const am_Handle_s& handle, const am_sourceID_t& sourceID, const am_NotificationConfiguration_s& notificationConfiguration, AsyncSetSourceNotificationConfigurationAsyncCallback callback);
-
+
/**
* Returns the CommonAPI address of the remote partner this proxy communicates with.
@@ -480,15 +474,15 @@ std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>:
/**
* connects a source to a sink
(at)return E_OK on success, E_UNKNOWN on error,
* E_WRONG_FORMAT in case am_ConnectionFormat_e does not match
*/
template <typename ... _AttributeExtensions>
-void RoutingControlProxy<_AttributeExtensions...>::asyncConnect(const am_Handle_s& handle, const am_connectionID_t& connectionID, const am_sourceID_t& sourceID, const am_sinkID_t& sinkID, const am_ConnectionFormat_pe& connectionFormat, CommonAPI::CallStatus& callStatus) {
+void RoutingControlProxy<_AttributeExtensions...>::asyncConnect(const am_Handle_s& handle, const am_connectionID_t& connectionID, const am_sourceID_t& sourceID, const am_sinkID_t& sinkID, const am_CustomConnectionFormat_t& connectionFormat, CommonAPI::CallStatus& callStatus) {
delegate_->asyncConnect(handle, connectionID, sourceID, sinkID, connectionFormat, callStatus);
}
template <typename ... _AttributeExtensions>
-std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>::asyncConnectAsync(const am_Handle_s& handle, const am_connectionID_t& connectionID, const am_sourceID_t& sourceID, const am_sinkID_t& sinkID, const am_ConnectionFormat_pe& connectionFormat, AsyncConnectAsyncCallback callback) {
+std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>::asyncConnectAsync(const am_Handle_s& handle, const am_connectionID_t& connectionID, const am_sourceID_t& sourceID, const am_sinkID_t& sinkID, const am_CustomConnectionFormat_t& connectionFormat, AsyncConnectAsyncCallback callback) {
return delegate_->asyncConnectAsync(handle, connectionID, sourceID, sinkID, connectionFormat, callback);
}
/**
@@ -513,12 +507,12 @@ std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>:
* E_OUT_OF_RANGE if new volume is out of range
*/
template <typename ... _AttributeExtensions>
-void RoutingControlProxy<_AttributeExtensions...>::asyncSetSinkVolume(const am_Handle_s& handle, const am_sinkID_t& sinkID, const am_volume_t& volume, const am_RampType_pe& ramp, const am_time_t& time, CommonAPI::CallStatus& callStatus) {
+void RoutingControlProxy<_AttributeExtensions...>::asyncSetSinkVolume(const am_Handle_s& handle, const am_sinkID_t& sinkID, const am_volume_t& volume, const am_CustomRampType_t& ramp, const am_time_t& time, CommonAPI::CallStatus& callStatus) {
delegate_->asyncSetSinkVolume(handle, sinkID, volume, ramp, time, callStatus);
}
template <typename ... _AttributeExtensions>
-std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>::asyncSetSinkVolumeAsync(const am_Handle_s& handle, const am_sinkID_t& sinkID, const am_volume_t& volume, const am_RampType_pe& ramp, const am_time_t& time, AsyncSetSinkVolumeAsyncCallback callback) {
+std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>::asyncSetSinkVolumeAsync(const am_Handle_s& handle, const am_sinkID_t& sinkID, const am_volume_t& volume, const am_CustomRampType_t& ramp, const am_time_t& time, AsyncSetSinkVolumeAsyncCallback callback) {
return delegate_->asyncSetSinkVolumeAsync(handle, sinkID, volume, ramp, time, callback);
}
/**
@@ -531,12 +525,12 @@ std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>:
triggers the acknowledge ackSourceVolumeChange
*/
template <typename ... _AttributeExtensions>
-void RoutingControlProxy<_AttributeExtensions...>::asyncSetSourceVolume(const am_Handle_s& handle, const am_sourceID_t& sourceID, const am_volume_t& volume, const am_RampType_pe& ramp, const am_time_t& time, CommonAPI::CallStatus& callStatus) {
+void RoutingControlProxy<_AttributeExtensions...>::asyncSetSourceVolume(const am_Handle_s& handle, const am_sourceID_t& sourceID, const am_volume_t& volume, const am_CustomRampType_t& ramp, const am_time_t& time, CommonAPI::CallStatus& callStatus) {
delegate_->asyncSetSourceVolume(handle, sourceID, volume, ramp, time, callStatus);
}
template <typename ... _AttributeExtensions>
-std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>::asyncSetSourceVolumeAsync(const am_Handle_s& handle, const am_sourceID_t& sourceID, const am_volume_t& volume, const am_RampType_pe& ramp, const am_time_t& time, AsyncSetSourceVolumeAsyncCallback callback) {
+std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>::asyncSetSourceVolumeAsync(const am_Handle_s& handle, const am_sourceID_t& sourceID, const am_volume_t& volume, const am_CustomRampType_t& ramp, const am_time_t& time, AsyncSetSourceVolumeAsyncCallback callback) {
return delegate_->asyncSetSourceVolumeAsync(handle, sourceID, volume, ramp, time, callback);
}
/**
@@ -615,12 +609,12 @@ std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>:
* error
*/
template <typename ... _AttributeExtensions>
-void RoutingControlProxy<_AttributeExtensions...>::asyncCrossFade(const am_Handle_s& handle, const am_crossfaderID_t& crossfaderID, const am_HotSink_e& hotSink, const am_RampType_pe& rampType, const am_time_t& time, CommonAPI::CallStatus& callStatus) {
+void RoutingControlProxy<_AttributeExtensions...>::asyncCrossFade(const am_Handle_s& handle, const am_crossfaderID_t& crossfaderID, const am_HotSink_e& hotSink, const am_CustomRampType_t& rampType, const am_time_t& time, CommonAPI::CallStatus& callStatus) {
delegate_->asyncCrossFade(handle, crossfaderID, hotSink, rampType, time, callStatus);
}
template <typename ... _AttributeExtensions>
-std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>::asyncCrossFadeAsync(const am_Handle_s& handle, const am_crossfaderID_t& crossfaderID, const am_HotSink_e& hotSink, const am_RampType_pe& rampType, const am_time_t& time, AsyncCrossFadeAsyncCallback callback) {
+std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>::asyncCrossFadeAsync(const am_Handle_s& handle, const am_crossfaderID_t& crossfaderID, const am_HotSink_e& hotSink, const am_CustomRampType_t& rampType, const am_time_t& time, AsyncCrossFadeAsyncCallback callback) {
return delegate_->asyncCrossFadeAsync(handle, crossfaderID, hotSink, rampType, time, callback);
}
/**
@@ -705,7 +699,6 @@ CommonAPI::InterfaceVersionAttribute& RoutingControlProxy<_AttributeExtensions..
return delegate_->getInterfaceVersionAttribute();
}
-
} // namespace am
} // namespace genivi
@@ -73,7 +67,7 @@ class RoutingControlProxy: virtual public RoutingControl, virtual public Routing
* connects a source to a sink
(at)return E_OK on success, E_UNKNOWN on error,
- * E_WRONG_FORMAT in case am_ConnectionFormat_e does not match
+ * E_WRONG_FORMAT in case am_CustomConnectionFormat_t does not match
*
* Calls asyncConnect with synchronous semantics.
@@ -480,15 +474,15 @@ std::future<CommonAPI::CallStatus> RoutingControlProxy<_AttributeExtensions...>:
* connects a source to a sink
(at)return E_OK on success, E_UNKNOWN on error,
- * E_WRONG_FORMAT in case am_ConnectionFormat_e does not match
+ * E_WRONG_FORMAT in case am_CustomConnectionFormat_t does not match
*/
template <typename ... _AttributeExtensions>